@@ -1,5 +1,8 @@
+# flake8: noqa
+from .wsireg2d import WsiReg2D
+
 """wsireg."""
 
 __author__ = """Nathan Heath Patterson"""
 __email__ = 'heath.patterson@vanderbilt.edu'
-__version__ = '0.3.0'
+__version__ = '0.3.2.2'
