@@ -1,27 +1,27 @@
-from pathlib import Path
 import multiprocessing
 import warnings
 from concurrent.futures import ThreadPoolExecutor
-import numpy as np
+from pathlib import Path
+
 import cv2
-import SimpleITK as sitk
-from tifffile import (
-    create_output,
-    TiffFile,
-    xml2dict,
-    TiffWriter,
-    imread,
-    OmeXml,
-)
-from czifile import CziFile
-import zarr
 import dask.array as da
-from wsireg.utils.tform_utils import (
-    sitk_transform_image,
+import numpy as np
+import SimpleITK as sitk
+import zarr
+from czifile import CziFile
+from tifffile import (
+    OmeXml,
+    TiffFile,
+    TiffWriter,
+    create_output,
+    imread,
+    xml2dict,
 )
 
+from wsireg.parameter_maps.preprocessing import BoundingBox
+from wsireg.utils.tform_utils import sitk_transform_image
 
-TIFFFILE_EXTS = [".scn", ".tif", ".tiff", ".ndpi"]
+TIFFFILE_EXTS = [".scn", ".tif", ".tiff", ".ndpi", ".svs"]
 
 ARRAYLIKE_CLASSES = (np.ndarray, da.core.Array, zarr.Array)
 
@@ -104,7 +104,7 @@ def read_preprocess_array(array, preprocessing, force_rgb=None):
     is_rgb = is_interleaved if not force_rgb else force_rgb
 
     if is_rgb:
-        if preprocessing is not None:
+        if preprocessing:
             image_out = np.asarray(
                 grayscale(array, is_interleaved=is_interleaved)
             )
@@ -119,12 +119,9 @@ def read_preprocess_array(array, preprocessing, force_rgb=None):
         image_out = sitk.GetImageFromArray(np.asarray(array))
 
     else:
-        if preprocessing is not None:
-            if (
-                preprocessing.get("ch_indices") is not None
-                and len(array.shape) > 2
-            ):
-                chs = list(preprocessing.get('ch_indices'))
+        if preprocessing:
+            if preprocessing.ch_indices and len(array.shape) > 2:
+                chs = list(preprocessing.ch_indices)
                 array = array[chs, :, :]
 
         image_out = sitk.GetImageFromArray(np.squeeze(np.asarray(array)))
@@ -1384,7 +1381,7 @@ def compute_mask_to_bbox(mask, mask_padding=100):
     x_width = x_max - x_min
     y_height = y_max - y_min
 
-    return (x_min, y_min, x_width, y_height)
+    return BoundingBox(x_min, y_min, x_width, y_height)
 
 
 def sitk_vect_to_gs(image):
@@ -1519,9 +1516,9 @@ def ome_tifffile_to_arraylike(image_filepath):
         image = image[0]
 
     image = da.from_zarr(image)
-
-    if is_rgb is False and samples_per_pixel >= 3:
-        image = image.transpose(1, 2, 0)
+    if samples_per_pixel:
+        if is_rgb is False and samples_per_pixel >= 3:
+            image = image.transpose(1, 2, 0)
 
     return image, image_filepath
 
