@@ -1,14 +1,15 @@
+import json
+import zipfile
 from copy import deepcopy
 from pathlib import Path
-import json
-import numpy as np
-import SimpleITK as sitk
+
 import cv2
 import geojson
+import numpy as np
+import SimpleITK as sitk
+
 from wsireg.reg_transform import RegTransform
-from wsireg.utils.tform_utils import (
-    wsireg_transforms_to_itk_composite,
-)
+from wsireg.utils.tform_utils import wsireg_transforms_to_itk_composite
 
 GJ_SHAPE_TYPE = {
     "polygon": geojson.Polygon,
@@ -60,7 +61,7 @@ def gj_to_np(gj: dict):
         shape_name = gj.get("properties").get("classification").get("name")
 
     return {
-        "array": pts,
+        "array": pts.astype(np.double),
         "shape_type": gj.get("geometry").get("type"),
         "shape_name": shape_name,
     }
@@ -89,7 +90,14 @@ def read_geojson(json_file: str):
             "shape_type": str - indicates GeoJSON shape_type (Polygon, MultiPolygon, etc.)
             "shape_name": str - name inherited from QuPath GeoJSON
     """
-    gj_data = json.load(open(json_file, "r"))
+    if Path(json_file).suffix != ".zip":
+        gj_data = json.load(open(json_file, "r"))
+    else:
+        with zipfile.ZipFile(json_file, "r") as z:
+            for filename in z.namelist():
+                with z.open(filename) as f:
+                    data = f.read()
+                    gj_data = json.loads(data.decode("utf-8"))
 
     shapes_np = [gj_to_np(s) for s in gj_data]
     gj_data = [add_unamed(gj) for gj in gj_data]
@@ -177,17 +185,20 @@ def shape_reader(shape_data, **kwargs):
             if Path(sh).is_file():
                 sh_fp = Path(sh)
 
-                if sh_fp.suffix == ".json":
+                if sh_fp.suffix in [".json", ".geojson", ".zip"]:
                     out_shape_gj, out_shape_np = read_geojson(str(sh_fp))
                 # elif sh_fp.suffix == ".cz":
                 #     out_shape_gj = read_zen_shapes(str(sh_fp))
                 #     out_shape_np = [gj_to_np(s) for s in out_shape_gj]
                 else:
                     raise ValueError(
-                        "{} is not a geojson, Zeiss Zen shape file or numpy array".format(
-                            str(sh_fp)
-                        )
+                        "{} is not a geojson or numpy array".format(str(sh_fp))
                     )
+            else:
+                raise FileNotFoundError(
+                    "{} file not found".format(str(sh_fp.as_posix()))
+                )
+
         if isinstance(out_shape_gj, list):
             shapes_gj.extend(out_shape_gj)
         else:
@@ -223,7 +234,7 @@ def scale_shape_coordinates(poly: dict, scale_factor: float):
     return poly
 
 
-def invert_nonlinear_transforms(itk_transforms: list):
+def invert_nonrigid_transforms(itk_transforms: list):
     """
     Check list of sequential ITK transforms for non-linear (i.e., bspline) transforms
     Transformations need to be inverted to transform from moving to fixed space as transformations
@@ -249,7 +260,7 @@ def invert_nonlinear_transforms(itk_transforms: list):
     else:
         nl_idxs = np.where(np.array(tform_linear) == 0)[0]
         for nl_idx in nl_idxs:
-            if itk_transforms[nl_idx].inverse_transform is None:
+            if not itk_transforms[nl_idx].inverse_transform:
                 print(
                     f"transform at index {nl_idx} is non-linear and the inverse has not been computed\n"
                     "inverting displacement field(s)...\n"
@@ -280,11 +291,11 @@ def prepare_pt_transformation_data(transformations, compute_inverse=True):
         This is needed to map coordinates defined as pixel indices to physical coordinates and then back
     """
     if all([isinstance(t, RegTransform) for t in transformations]) is False:
-        composite, transformations = wsireg_transforms_to_itk_composite(
+        _, transformations = wsireg_transforms_to_itk_composite(
             transformations
         )
     if compute_inverse:
-        transformations = invert_nonlinear_transforms(transformations)
+        transformations = invert_nonrigid_transforms(transformations)
     target_res = float(transformations[-1].output_spacing[0])
     return transformations, target_res
 
