@@ -1,19 +1,21 @@
-from pathlib import Path
 import json
-import numpy as np
+from pathlib import Path
+from typing import Tuple, Union
+
 import itk
+import numpy as np
 import SimpleITK as sitk
-from wsireg.utils.reg_utils import json_to_pmap_dict
-from wsireg.utils.itk_im_conversions import (
-    sitk_image_to_itk_image,
-    itk_image_to_sitk_image,
-)
+
 from wsireg.parameter_maps.transformations import (
-    BASE_RIG_TFORM,
     BASE_AFF_TFORM,
+    BASE_RIG_TFORM,
 )
 from wsireg.reg_transform import RegTransform
-
+from wsireg.utils.itk_im_conversions import (
+    itk_image_to_sitk_image,
+    sitk_image_to_itk_image,
+)
+from wsireg.utils.reg_utils import json_to_pmap_dict
 
 NUMERIC_ELX_PARAMETERS = {
     "CenterOfRotationPoint": np.float64,
@@ -577,6 +579,16 @@ def sitk_transform_image(image, final_tform, composite_transform):
     return image
 
 
+def identity_elx_transform(
+    image_size: Tuple[int, int],
+    image_spacing: Union[Tuple[int, int], Tuple[float, float]],
+):
+    identity = BASE_RIG_TFORM
+    identity.update({"Size": [str(i) for i in image_size]})
+    identity.update({"Spacing": [str(i) for i in image_spacing]})
+    return identity
+
+
 #
 # def apply_transform_dict(
 #     image_fp,
